==> humhub-1.8.0-beta.1.tar.gz: humhub-1.8.0-beta.1/protected/humhub/modules/user/messages/de/base.php <==
<?php
return array (
  '<strong>Following</strong> user' => 'Der Benutzer <strong>folgt</strong>',
  '<strong>Member</strong> in these spaces' => '<strong>Mitglied</strong> in diesen Spaces',
  '<strong>User</strong> followers' => 'Dem <strong>Benutzer</strong> folgen',
  '<strong>User</strong> tags' => '<strong>Benutzer</strong>-Tags',
  'Allows access to your about page with personal information' => 'Zugriff auf deine Info-Seite mit persönlichen Informationen erlauben',
  'Auth Mode' => 'Auth-Verfahren',
  'Basic Settings' => 'Grundeinstellungen',
  'Change Email' => 'E-Mail ändern',
  'Change Password' => 'Passwort ändern',
  'Change Username' => 'Benutzernamen ändern',
  'Confirm new password' => 'Neues Passwort bestätigen',
  'Connect account' => 'Konto verbinden',
  'Connected Accounts' => 'Verbundene Konten',
  'Connected accounts' => 'Verbundene Konten',
  'Created at' => 'Erstellt am',
  'Created by' => 'Erstellt durch',
  'Current password' => 'Aktuelles Passwort',
  'Currently in use' => 'Zurzeit in Benutzung',
  'Default Group' => 'Standard-Gruppe',
  'Default Space' => 'Standard-Space',
  'Delete' => 'Löschen',
  'Delete Account' => 'Benutzerkonto löschen',
  'Description' => 'Beschreibung',
  'Disconnect account' => 'Benutzerkonto trennen',
  'E-Mail is already in use! - Try forgot password.' => 'Diese E-Mail Adresse ist bereits registriert! - Versuche "Passwort vergessen".',
  'Email' => 'E-Mail',
  'Enable Notifications' => 'Benachrichtigungen aktivieren',
  'Follow' => 'Folgen',
  'Force password change upon first login' => 'Passwortänderung bei erster Anmeldung erzwingen',
  'Force password change upon next login' => 'Passwortänderung bei zweiter Anmeldung erzwingen',
  'General' => 'Allgemein',
  'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Hier kannst du dich mit einem externen Dienstanbieter verbinden, um externe Dienste wie eine Single Sign On Authentifizierung zu nutzen.',
  'Language' => 'Sprache',
  'Last Login' => 'Letzter Login',
  'Manager' => 'Manager',
  'Missing E-Mail Attribute from AuthClient.' => 'Fehlendes E-Mail Attribut über AuthClient',
  'Missing ID AuthClient Attribute from AuthClient.' => 'Fehlendes AuthClient-ID Attribut über AuthClient',
  'Modules' => 'Module',
  'My Account' => 'Mein Benutzerkonto',
  'Name' => 'Name',
  'New password' => 'Neues Passwort',
  'No users found.' => 'Keine Benutzer gefunden.',
  'Notifications' => 'Mitteilungen',
  'Password' => 'Passwort',
  'Password changed' => 'Passwort geändert',
  'Password needs to be at least {chars} characters long.' => 'Das Passwort muss mindestens {chars} Zeichen lang sein.',
  'Permission' => 'Berechtigung',
  'Profile' => 'Profil',
  'Profile posts only' => 'Nur Profil Beiträge',
  'Register now and participate!' => 'Jetzt registieren und teilnehmen!',
  'Security' => 'Sicherheit',
  'Settings' => 'Einstellungen',
  'Show At Directory' => 'Im Verzeichnis anzeigen',
  'Show At Registration' => 'Bei Registrierung anzeigen',
  'Show all content' => 'Zeige alle Inhalte',
  'Sign in' => 'Einloggen',
  'Sign in / up' => 'Einloggen | Registrieren',
  'Sign up' => 'Registrieren',
  'Sign up now' => 'Jetzt registrieren',
  'Sort order' => 'Sortierung',
  'Source' => 'Quelle',
  'Status' => 'Status',
  'Tags' => 'Tags',
  'Unfollow' => 'Nicht mehr folgen',
  'Unknown user status!' => 'Unbekannter User-Status!',
  'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Gescheiterte Anmeldeversuche seit letzter Anmeldung: {failedLoginAttemptsCount}',
  'Updated at' => 'Geändert am',
  'Updated by' => 'Geändert durch',
  'User' => 'Benutzer',
  'User has been invited.' => 'Der Benutzer wurde eingeladen.',
  'Username' => 'Benutzername',
  'Username contains invalid characters.' => 'Benutzername enthält ungültige Sonderzeichen.',
  'View your about page' => 'Deine Info-Seite ansehen',
  'Visibility' => 'Sichtbarkeit',
  'Welcome to %appName%' => 'Willkommen bei %appName%',
  'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Willkommen bei %appName%. Bitte klicke auf den Button unten, um mit der Registrierung fortzufahren.',
  'You got an invite' => 'Du wurdest eingeladen',
  'You\'re not registered.' => 'Du bist noch nicht registriert.',
  'You\'ve been invited to join {space} on {appName}' => 'Du wurdest eingeladen, dem Space {space} auf {appName} beizutreten',
  'Your account is disabled!' => 'Dein Benutzerkonto ist deaktiviert!',
  'Your account is not approved yet!' => 'Dein Benutzerkonto wurde noch nicht freigeschaltet!',
  'Your are already logged in! - Logout first!' => 'Du bist bereits angemeldet!',
  'Your new password must not be equal your current password!' => 'Das neue Passwort darf nicht mit dem aktuellen Passwort übereinstimmen!',
  'invited you to join {name}.' => 'hat dich zu {name} eingeladen',
  'invited you to join {space} on {name}.' => 'hat dich auf {name} eingeladen {space} beizutreten',
  'or' => 'oder',
);

==> humhub-1.15.0-beta.1.tar.gz: humhub-1.15.0-beta.1/protected/humhub/modules/user/messages/de/base.php <==
<?php
return array (
  '<strong>Followers</strong>' => '<strong>Mir folgen</strong>',
  '<strong>Following</strong>' => '<strong>Ich folge</strong>',
  '<strong>Group</strong> members - {group}' => '<strong>Gruppen-</strong>Mitglieder - {group}',
  '<strong>Member</strong> in these spaces' => '<strong>Mitgliedschaften</strong>',
  '<strong>Member</strong> of these Spaces' => '<strong>Mitgliedschaften</strong>',
  '<strong>People</strong>' => '<strong>Mitgliederverzeichnis</strong>',
  '<strong>User</strong> tags' => '<strong>Tags</strong>',
  'All' => 'Alle',
  'Allow users to mention you' => 'Erlaube Benutzern dich zu erwähnen',
  'Allows access to your about page with personal information' => 'Zugriff auf deine Info-Seite mit persönlichen Informationen erlauben',
  'Any' => 'Alle',
  'Auth Mode' => 'Auth-Verfahren',
  'Basic Settings' => 'Grundeinstellungen',
  'Change Email' => 'E-Mail ändern',
  'Change Password' => 'Passwort ändern',
  'Change Username' => 'Benutzernamen ändern',
  'Confirm new password' => 'Neues Passwort bestätigen',
  'Connect account' => 'Konto verbinden',
  'Connected Accounts' => 'Verbundene Konten',
  'Connected accounts' => 'Verbundene Konten',
  'Created at' => 'Erstellt am',
  'Created by' => 'Erstellt durch',
  'Current password' => 'Aktuelles Passwort',
  'Currently in use' => 'Zurzeit in Benutzung',
  'Default Group' => 'Standard-Gruppe',
  'Default Space' => 'Standard-Space',
  'Delete' => 'Löschen',
  'Delete Account' => 'Benutzerkonto löschen',
  'Description' => 'Beschreibung',
  'Did you forget your password?' => '',
  'Disconnect account' => 'Benutzerkonto trennen',
  'Email' => 'E-Mail',
  'Enable Notifications' => 'Benachrichtigungen aktivieren',
  'Find people by their profile data or user tags' => 'Finde Benutzer anhand ihrer Profildaten und "Tags"',
  'Follow' => 'Folgen',
  'Followers' => 'Follower',
  'Following' => 'Folgend',
  'Following (User)' => 'Following (Benutzer)',
  'Force password change upon first login' => 'Passwortänderung bei erster Anmeldung erzwingen',
  'Force password change upon next login' => 'Passwortänderung bei zweiter Anmeldung erzwingen',
  'Friends' => 'Freunde',
  'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Hier kannst du dich mit einem externen Dienstanbieter verbinden, um externe Dienste wie eine Single Sign On Authentifizierung zu nutzen.',
  'If this wasn\'t you, you can disregard this message.' => '',
  'Invite by email' => 'Per E-Mail einladen',
  'Invite by link' => 'Per Link einladen',
  'Invite new people' => 'Neue Benutzer einladen',
  'Invited by' => 'Eingeladen von',
  'It looks like you clicked on an invalid password reset link. Please try again.' => '',
  'Language' => 'Sprache',
  'Last Login' => 'Letzter Login',
  'Manager' => 'Manager',
  'Mentioning' => 'Erwähnungen',
  'Missing E-Mail Attribute from AuthClient.' => 'Fehlendes E-Mail Attribut über AuthClient',
  'Missing ID AuthClient Attribute from AuthClient.' => 'Fehlendes AuthClient-ID Attribut über AuthClient',
  'Modules' => 'Module',
  'My Account' => 'Mein Benutzerkonto',
  'Name' => 'Name',
  'New password' => 'Neues Passwort',
  'No results found!' => 'Keine Ergebnisse gefunden!',
  'No users found.' => 'Keine Benutzer gefunden.',
  'Notifications' => 'Benachrichtigungen',
  'Offline' => '',
  'Online' => '',
  'Password' => 'Passwort',
  'Password changed' => 'Passwort geändert',
  'Password needs to be at least {chars} characters long.' => 'Das Passwort muss mindestens {chars} Zeichen lang sein.',
  'Password recovery' => 'Passwort-Wiederherstellung',
  'Pending Requests' => 'Offene Anfragen',
  'People' => 'Mitglieder',
  'Permission' => 'Berechtigung',
  'Profile' => 'Profil',
  'Profile posts only' => 'Nur Profil Beiträge',
  'Register now and participate!' => 'Jetzt registrieren und teilnehmen!',
  'Search...' => 'Suchen..',
  'Security' => 'Sicherheit',
  'Settings' => 'Einstellungen',
  'Show At Registration' => 'Bei Registrierung anzeigen',
  'Show all content' => 'Zeige alle Inhalte',
  'Sign in' => 'Einloggen',
  'Sign in / up' => 'Einloggen | Registrieren',
  'Sign up' => 'Registrieren',
  'Sign up now' => 'Jetzt registrieren',
  'Sort order' => 'Sortierung',
  'Source' => 'Quelle',
  'Status' => 'Status',
  'Tags' => 'Tags',
  'The secure link has been copied in your clipboard!' => 'Der Link wurde in deine Zwischenablage kopiert!',
  'Try other keywords or remove filters.' => 'Verwende andere Suchbegriffe oder ändere die Filtereinstellungen.',
  'Unknown user status!' => 'Unbekannter User-Status!',
  'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Gescheiterte Anmeldeversuche seit letzter Anmeldung: {failedLoginAttemptsCount}',
  'Updated at' => 'Geändert am',
  'Updated by' => 'Geändert durch',
  'User' => 'Benutzer',
  'User Group' => 'Benutzergruppe',
  'User has been invited.' => 'Der Benutzer wurde eingeladen.',
  'Username' => 'Benutzername',
  'Username contains invalid characters.' => 'Benutzername enthält ungültige Sonderzeichen.',
  'View your about page' => 'Deine Info-Seite ansehen',
  'Visibility' => 'Sichtbarkeit',
  'Visible' => 'Sichtbar',
  'Welcome to %appName%' => 'Willkommen bei %appName%',
  'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Willkommen bei %appName%. Bitte klicke auf den Button unten, um mit der Registrierung fortzufahren.',
  'Whenever a user follows another user.' => 'Wenn ein Benutzer einem anderen Benutzer folgt.',
  'You got an invite' => 'Du wurdest eingeladen',
  'You tried registering an account with %appName%, but already have an account associated with this email address.' => '',
  'You\'re not registered.' => 'Du bist noch nicht registriert.',
  'You\'ve been invited to join {space} on {appName}' => 'Du wurdest eingeladen, dem Space {space} auf {appName} beizutreten',
  'Your account is disabled!' => 'Dein Benutzerkonto ist deaktiviert!',
  'Your account is not approved yet!' => 'Dein Benutzerkonto wurde noch nicht freigeschaltet!',
  'Your are already logged in! - Logout first!' => 'Du bist bereits angemeldet!',
  'Your new password must not be equal your current password!' => 'Das neue Passwort darf nicht mit dem aktuellen Passwort übereinstimmen!',
  'invited you to join {name}.' => 'hat dich zu {name} eingeladen',
  'invited you to join {space} on {name}.' => 'hat dich auf {name} eingeladen {space} beizutreten',
  'or' => 'oder',
);
